@@ -54,7 +54,7 @@ class collect_external_io_metrics(ContextDecorator):
             status = 'error'
             exception_type = exc_type.__class__.__name__
         else:
-            status = 'success',
+            status = 'success'
             exception_type = None
 
         metric_name = create_external_service_duration_metrics(status, time_taken_ms, self.io_name,
