@@ -358,7 +358,7 @@ def create_external_service_duration_metrics(status, duration_ms, name, address,
                 'name': name,
                 'address': address,
                 'exception_class': exception_type,
-                'external_tag': tag
+                'tag': tag
             })
             statsd_client.incr(exception_metric)
             logger.debug('Incremented metric {}'.format(exception_metric))
@@ -367,7 +367,8 @@ def create_external_service_duration_metrics(status, duration_ms, name, address,
     hist_metric = add_label_to_metric_without_mapping(hist_metric, {
         'name': name,
         'address': address,
-        'status': status
+        'status': status,
+        'tag': tag
     })
 
     if labels_dict:
@@ -381,7 +382,8 @@ def create_external_service_duration_metrics(status, duration_ms, name, address,
     service_duration_gauge_metric = add_label_to_metric_without_mapping(service_duration_gauge_metric, {
         'name': name,
         'address': address,
-        'status': status
+        'status': status,
+        'tag': tag
     })
 
     statsd_client.gauge(service_duration_gauge_metric, duration_ms)
@@ -419,6 +421,6 @@ def create_external_io_counter_metric(name, address, tag):
     })
 
     statsd_client.incr(external_io_counter)
-    logger.debug('Incremented histogram metric {}'.format(external_io_counter))
+    logger.debug('Incremented External IO Counter metric {}'.format(external_io_counter))
 
     return external_io_counter
